@@ -4,10 +4,10 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.301001_047';
+our $VERSION = '1.301001_051';
 $VERSION = eval $VERSION;    ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
-use Test::Stream::Carp qw/croak/;
+use Test::Stream::Carp qw/croak carp/;
 use Scalar::Util qw/blessed/;
 use Encode();
 
@@ -134,7 +134,7 @@ sub before_import {
             $meta->[ENCODING] = $encoding;
         }
         else {
-            Carp::carp("Unknown option: $item");
+            carp("Unknown option: $item");
         }
     }
 
@@ -147,7 +147,7 @@ sub before_import {
 
 sub ok ($;$) {
     my $ctx = context();
-    return $ctx->ok(@_);
+    $ctx->ok(@_);
     return $_[0] ? 1 : 0;
 }
 
@@ -1761,14 +1761,14 @@ L<Bundle::Test> installs a whole bunch of useful test modules.
 
 L<Test::Most> Most commonly needed test functions and features.
 
-=head1 AUTHORS
+=encoding utf8
 
-Michael G Schwern E<lt>schwern@pobox.comE<gt> with much inspiration
-from Joshua Pritikin's Test module and lots of help from Barrie
-Slaymaker, Tony Bowden, blackstar.co.uk, chromatic, Fergal Daly and
-the perl-qa gang.
+=head1 SOURCE
 
-=head1 MAINTAINERS
+The source code repository for Test::More can be found at
+F<http://github.com/Test-More/test-more/>.
+
+=head1 MAINTAINER
 
 =over 4
 
@@ -1776,16 +1776,32 @@ the perl-qa gang.
 
 =back
 
+=head1 AUTHORS
 
-=head1 SOURCE
+The following people have all contributed to the Test-More dist (sorted using
+VIM's sort function).
 
-The source code repository for Test::More can be found at
-F<http://github.com/Test-More/test-more/>.
+=over 4
 
+=item Chad Granum E<lt>exodist@cpan.orgE<gt>
+
+=item Fergal Daly E<lt>fergal@esatclear.ie>E<gt>
+
+=item Mark Fowler E<lt>mark@twoshortplanks.comE<gt>
+
+=item Michael G Schwern E<lt>schwern@pobox.comE<gt>
+
+=item 唐鳳
+
+=back
 
 =head1 COPYRIGHT
 
-Copyright 2001-2008 by Michael G Schwern E<lt>schwern@pobox.comE<gt>.
+=over 4
+
+=item Test::Stream
+
+=item Test::Tester2
 
 Copyright 2014 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 
@@ -1794,3 +1810,50 @@ modify it under the same terms as Perl itself.
 
 See F<http://www.perl.com/perl/misc/Artistic.html>
 
+=item Test::Simple
+
+=item Test::More
+
+=item Test::Builder
+
+Originally authored by Michael G Schwern E<lt>schwern@pobox.comE<gt> with much
+inspiration from Joshua Pritikin's Test module and lots of help from Barrie
+Slaymaker, Tony Bowden, blackstar.co.uk, chromatic, Fergal Daly and the perl-qa
+gang.
+
+Idea by Tony Bowden and Paul Johnson, code by Michael G Schwern
+E<lt>schwern@pobox.comE<gt>, wardrobe by Calvin Klein.
+
+Copyright 2001-2008 by Michael G Schwern E<lt>schwern@pobox.comE<gt>.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+See F<http://www.perl.com/perl/misc/Artistic.html>
+
+=item Test::use::ok
+
+To the extent possible under law, 唐鳳 has waived all copyright and related
+or neighboring rights to L<Test-use-ok>.
+
+This work is published from Taiwan.
+
+L<http://creativecommons.org/publicdomain/zero/1.0>
+
+=item Test::Tester
+
+This module is copyright 2005 Fergal Daly <fergal@esatclear.ie>, some parts
+are based on other people's work.
+
+Under the same license as Perl itself
+
+See http://www.perl.com/perl/misc/Artistic.html
+
+=item Test::Builder::Tester
+
+Copyright Mark Fowler E<lt>mark@twoshortplanks.comE<gt> 2002, 2004.
+
+This program is free software; you can redistribute it
+and/or modify it under the same terms as Perl itself.
+
+=back
