@@ -253,10 +253,12 @@ sub new_check {
 sub _require_check {
     my ($us, $thing, $version, $force_module, $sigdie) = @_;
 
+    no warnings 'uninitialized';
     local $SIG{__DIE__} = undef;
+    use warnings;
 
     my $ctx = context();
-    my $fool_me = "#line " . $ctx->line . ' "' . $ctx->file . '"';
+    my $fool_me = "package " . $ctx->package . ";\n#line " . $ctx->line . ' "' . $ctx->file . '"';
     my $file_exists;
     protect { $file_exists = !$version && !$force_module && -f $thing };
     my $valid_name = !grep { m/^[a-zA-Z]\w*$/ ? 0 : 1 } split /\b::\b/, $thing;
@@ -346,9 +348,12 @@ sub use_check {
     my $sigdie = undef;
     my $ctx = context();
     my ($succ, $error) = try {
+        no warnings 'uninitialized';
         local $SIG{__DIE__} = undef;
+        use warnings;
         my ($p, $f, $l) = $ctx->call;
-        eval qq{package $p;\n#line $l "$f"\n\$module->import(\@imports); 1} || die $@;
+        my $imp = @imports ? '@imports' : "";
+        eval qq{package $p;\n#line $l "$f"\n\$module->import($imp); 1} || die $@;
         $sigdie = $SIG{__DIE__} if defined $SIG{__DIE__};
     };
 
@@ -475,3 +480,101 @@ sub subtest {
 
 1;
 
+__END__
+
+=encoding utf8
+
+=head1 SOURCE
+
+The source code repository for Test::More can be found at
+F<http://github.com/Test-More/test-more/>.
+
+=head1 MAINTAINER
+
+=over 4
+
+=item Chad Granum E<lt>exodist@cpan.orgE<gt>
+
+=back
+
+=head1 AUTHORS
+
+The following people have all contributed to the Test-More dist (sorted using
+VIM's sort function).
+
+=over 4
+
+=item Chad Granum E<lt>exodist@cpan.orgE<gt>
+
+=item Fergal Daly E<lt>fergal@esatclear.ie>E<gt>
+
+=item Mark Fowler E<lt>mark@twoshortplanks.comE<gt>
+
+=item Michael G Schwern E<lt>schwern@pobox.comE<gt>
+
+=item 唐鳳
+
+=back
+
+=head1 COPYRIGHT
+
+=over 4
+
+=item Test::Stream
+
+=item Test::Tester2
+
+Copyright 2014 Chad Granum E<lt>exodist7@gmail.comE<gt>.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+See F<http://www.perl.com/perl/misc/Artistic.html>
+
+=item Test::Simple
+
+=item Test::More
+
+=item Test::Builder
+
+Originally authored by Michael G Schwern E<lt>schwern@pobox.comE<gt> with much
+inspiration from Joshua Pritikin's Test module and lots of help from Barrie
+Slaymaker, Tony Bowden, blackstar.co.uk, chromatic, Fergal Daly and the perl-qa
+gang.
+
+Idea by Tony Bowden and Paul Johnson, code by Michael G Schwern
+E<lt>schwern@pobox.comE<gt>, wardrobe by Calvin Klein.
+
+Copyright 2001-2008 by Michael G Schwern E<lt>schwern@pobox.comE<gt>.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+See F<http://www.perl.com/perl/misc/Artistic.html>
+
+=item Test::use::ok
+
+To the extent possible under law, 唐鳳 has waived all copyright and related
+or neighboring rights to L<Test-use-ok>.
+
+This work is published from Taiwan.
+
+L<http://creativecommons.org/publicdomain/zero/1.0>
+
+=item Test::Tester
+
+This module is copyright 2005 Fergal Daly <fergal@esatclear.ie>, some parts
+are based on other people's work.
+
+Under the same license as Perl itself
+
+See http://www.perl.com/perl/misc/Artistic.html
+
+=item Test::Builder::Tester
+
+Copyright Mark Fowler E<lt>mark@twoshortplanks.comE<gt> 2002, 2004.
+
+This program is free software; you can redistribute it
+and/or modify it under the same terms as Perl itself.
+
+=back
