@@ -15,7 +15,7 @@ require Exporter;
 
 use vars qw( @ISA @EXPORT $VERSION );
 
-our $VERSION = '1.301001_047';
+our $VERSION = '1.301001_051';
 $VERSION = eval $VERSION;    ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 @EXPORT  = qw( run_tests check_tests check_test cmp_results show_space );
@@ -42,17 +42,25 @@ if (my $want_colour = $ENV{TESTTESTERCOLOUR} || $ENV{TESTTESTERCOLOUR}) {
 my $capture = Test::Tester::Capture->new;
 sub capture { $capture }
 
-sub find_run_tests {
-    my $d     = 1;
-    my $found = 0;
-    while ((not $found) and (my ($sub) = (caller($d))[3])) {
-        $found = ($sub eq "Test::Tester::run_tests");
-        $d++;
+sub find_depth {
+    my ($start, $end);
+    my $l = 1;
+    while (my @call = caller($l++)) {
+        $start = $l if $call[3] =~ m/^Test::Builder::(ok|skip|todo_skip)$/;
+        next unless $start;
+        next unless $call[3] eq 'Test::Tester::run_tests';
+        $end = $l;
+        last;
     }
 
-    return $d;
+    # 2 the eval and the anon sub
+    return $end - $start - 2;
 }
 
+require Test::Stream::Event::Ok;
+my $META = Test::Stream::ArrayBase::Meta->get('Test::Stream::Event::Ok');
+my $idx = $META->{index} + 1;
+
 sub run_tests {
     my $test = shift;
 
@@ -64,6 +72,13 @@ sub run_tests {
     my ($stream, $old) = Test::Stream->intercept_start($cstream);
     $stream->set_use_legacy(1);
     $stream->state->[-1] = [0, 0, undef, 1];
+    $stream->munge(sub {
+        my ($stream, $e) = @_;
+        $e->[$idx] = find_depth() - $Test::Builder::Level;
+        $e->[$idx+1] = $Test::Builder::Level;
+        require Carp;
+        $e->[$idx + 2] = Carp::longmess();
+    });
 
     my $level = $Test::Builder::Level;
 
@@ -77,7 +92,7 @@ sub run_tests {
             if ($e->isa('Test::Stream::Event::Ok')) {
                 push @out => $e->to_legacy;
                 $out[-1]->{diag} ||= "";
-                $out[-1]->{depth} = $e->level - $level;
+                $out[-1]->{depth} = $e->[$idx];
                 for my $d (@{$e->diag || []}) {
                     next if $d->message =~ m{Failed test (.*\n\s*)?at .* line \d+\.};
                     next if $d->message =~ m{You named your test '.*'\.  You shouldn't use numbers for your test names};
@@ -651,22 +666,99 @@ captures the strings output by Test::Builder. This means you cannot get
 separate access to the individual pieces of information and you must predict
 B<exactly> what your test will output.
 
-=head1 AUTHOR
+=encoding utf8
+
+=head1 SOURCE
+
+The source code repository for Test::More can be found at
+F<http://github.com/Test-More/test-more/>.
+
+=head1 MAINTAINER
+
+=over 4
+
+=item Chad Granum E<lt>exodist@cpan.orgE<gt>
+
+=back
+
+=head1 AUTHORS
+
+The following people have all contributed to the Test-More dist (sorted using
+VIM's sort function).
+
+=over 4
+
+=item Chad Granum E<lt>exodist@cpan.orgE<gt>
+
+=item Fergal Daly E<lt>fergal@esatclear.ie>E<gt>
+
+=item Mark Fowler E<lt>mark@twoshortplanks.comE<gt>
+
+=item Michael G Schwern E<lt>schwern@pobox.comE<gt>
+
+=item 唐鳳
+
+=back
+
+=head1 COPYRIGHT
+
+=over 4
+
+=item Test::Stream
+
+=item Test::Tester2
+
+Copyright 2014 Chad Granum E<lt>exodist7@gmail.comE<gt>.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+See F<http://www.perl.com/perl/misc/Artistic.html>
+
+=item Test::Simple
+
+=item Test::More
+
+=item Test::Builder
+
+Originally authored by Michael G Schwern E<lt>schwern@pobox.comE<gt> with much
+inspiration from Joshua Pritikin's Test module and lots of help from Barrie
+Slaymaker, Tony Bowden, blackstar.co.uk, chromatic, Fergal Daly and the perl-qa
+gang.
+
+Idea by Tony Bowden and Paul Johnson, code by Michael G Schwern
+E<lt>schwern@pobox.comE<gt>, wardrobe by Calvin Klein.
+
+Copyright 2001-2008 by Michael G Schwern E<lt>schwern@pobox.comE<gt>.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+See F<http://www.perl.com/perl/misc/Artistic.html>
+
+=item Test::use::ok
+
+To the extent possible under law, 唐鳳 has waived all copyright and related
+or neighboring rights to L<Test-use-ok>.
+
+This work is published from Taiwan.
+
+L<http://creativecommons.org/publicdomain/zero/1.0>
+
+=item Test::Tester
 
 This module is copyright 2005 Fergal Daly <fergal@esatclear.ie>, some parts
 are based on other people's work.
 
-Plan handling lifted from Test::More. written by Michael G Schwern
-<schwern@pobox.com>.
-
-Test::Tester::Capture is a cut down and hacked up version of Test::Builder.
-Test::Builder was written by chromatic <chromatic@wgz.org> and Michael G
-Schwern <schwern@pobox.com>.
-
-=head1 LICENSE
-
 Under the same license as Perl itself
 
 See http://www.perl.com/perl/misc/Artistic.html
 
-=cut
+=item Test::Builder::Tester
+
+Copyright Mark Fowler E<lt>mark@twoshortplanks.comE<gt> 2002, 2004.
+
+This program is free software; you can redistribute it
+and/or modify it under the same terms as Perl itself.
+
+=back
